@@ -1,9 +1,10 @@
 import datetime
 import logging
-from typing import List, Optional
+from typing import Any, Dict, List, Optional
 
 import dateutil
 import dateutil.tz
+import more_itertools
 
 from annofabapi.models import Task, TaskHistory, TaskHistoryShort, TaskPhase
 
@@ -159,3 +160,19 @@ def can_put_annotation(task: Task, my_account_id: str) -> bool:
     """
     # ログインユーザはプロジェクトオーナであること前提
     return len(task["histories_by_phase"]) == 0 or task["account_id"] == my_account_id
+
+
+def get_message_for_i18n(internationalization_message: Dict[str, Any], lang: str = "en-US") -> Optional[str]:
+    """
+    アノテーション仕様で使われている`InternalizationMessage`クラスの値から、指定された言語のメッセージを取得する。
+
+    Args:
+        internationalization_message: 多言語化されたメッセージ
+        lang: 取得したいメッセージに対応する言語
+
+    Returns:
+        指定した言語に対応するメッセージ。見つからない場合はNoneを返します。
+    """
+
+    messages = internationalization_message["messages"]
+    return more_itertools.first_true(messages, pred=lambda e: e["lang"] == lang)
